@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2019, QIIME 2 development team.
+# Copyright (c) 2016-2020, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -10,7 +10,7 @@ import os.path
 import unittest
 
 import pandas as pd
-import pandas.io.common
+import pandas.errors
 import biom
 import skbio
 import qiime2
@@ -21,7 +21,7 @@ from q2_types.feature_data import (
     TaxonomyFormat, HeaderlessTSVTaxonomyFormat, TSVTaxonomyFormat,
     DNAFASTAFormat, DNAIterator, PairedDNAIterator,
     PairedDNASequencesDirectoryFormat, AlignedDNAFASTAFormat,
-    AlignedDNAIterator
+    DifferentialFormat, AlignedDNAIterator
 )
 from q2_types.feature_data._transformer import (
     _taxonomy_formats_to_dataframe, _dataframe_to_tsv_taxonomy_format)
@@ -264,6 +264,45 @@ class TestTaxonomyFormatTransformers(TestPluginBase):
 
         self.assertEqual(exp, obs)
 
+    def test_tsv_taxonomy_to_metadata_trailing_whitespace_taxon(self):
+        _, obs = self.transform_format(TSVTaxonomyFormat, qiime2.Metadata,
+                                       os.path.join(
+                                           'taxonomy',
+                                           'trailing_space_taxon.tsv'))
+
+        index = pd.Index(['seq1'], name='Feature ID', dtype=object)
+        exp_df = pd.DataFrame([['k__Foo; p__Bar', '-1.0']], index=index,
+                              columns=['Taxon', 'Confidence'], dtype=object)
+        exp = qiime2.Metadata(exp_df)
+
+        self.assertEqual(exp, obs)
+
+    def test_tsv_taxonomy_to_metadata_leading_whitespace_taxon(self):
+        _, obs = self.transform_format(TSVTaxonomyFormat, qiime2.Metadata,
+                                       os.path.join(
+                                           'taxonomy',
+                                           'leading_space_taxon.tsv'))
+
+        index = pd.Index(['seq1'], name='Feature ID', dtype=object)
+        exp_df = pd.DataFrame([['k__Foo; p__Bar', '-1.0']], index=index,
+                              columns=['Taxon', 'Confidence'], dtype=object)
+        exp = qiime2.Metadata(exp_df)
+
+        self.assertEqual(exp, obs)
+
+    def test_tsv_taxonomy_to_metadata_trailing_leading_whitespace_taxon(self):
+        _, obs = self.transform_format(TSVTaxonomyFormat, qiime2.Metadata,
+                                       os.path.join(
+                                           'taxonomy',
+                                           'start_end_space_taxon.tsv'))
+
+        index = pd.Index(['seq1'], name='Feature ID', dtype=object)
+        exp_df = pd.DataFrame([['k__Foo; p__Bar', '-1.0']], index=index,
+                              columns=['Taxon', 'Confidence'], dtype=object)
+        exp = qiime2.Metadata(exp_df)
+
+        self.assertEqual(exp, obs)
+
 
 # In-depth testing of the `_taxonomy_formats_to_dataframe` helper function,
 # which does the heavy lifting for the transformers.
@@ -275,14 +314,14 @@ class TestTaxonomyFormatsToDataFrame(TestPluginBase):
             _taxonomy_formats_to_dataframe(
                 self.get_data_path(os.path.join('taxonomy', '1-column.tsv')))
 
-    def test_blanks_and_comments(self):
-        with self.assertRaises(pandas.io.common.EmptyDataError):
+    def test_blanks(self):
+        with self.assertRaises(pandas.errors.EmptyDataError):
             _taxonomy_formats_to_dataframe(
                 self.get_data_path(os.path.join('taxonomy',
-                                                'blanks-and-comments')))
+                                                'blanks')))
 
     def test_empty(self):
-        with self.assertRaises(pandas.io.common.EmptyDataError):
+        with self.assertRaises(pandas.errors.EmptyDataError):
             _taxonomy_formats_to_dataframe(
                 self.get_data_path(os.path.join('taxonomy', 'empty')))
 
@@ -299,7 +338,7 @@ class TestTaxonomyFormatsToDataFrame(TestPluginBase):
                 has_header=True)
 
     def test_jagged(self):
-        with self.assertRaises(pandas.io.common.CParserError):
+        with self.assertRaises(pandas.errors.ParserError):
             _taxonomy_formats_to_dataframe(
                 self.get_data_path(os.path.join('taxonomy', 'jagged.tsv')))
 
@@ -655,6 +694,92 @@ class TestDNAFASTAFormatTransformers(TestPluginBase):
 
         self.assertEqual(exp, obs)
 
+    def test_aligned_dnafasta_format_to_series(self):
+        _, obs = self.transform_format(AlignedDNAFASTAFormat, pd.Series,
+                                       'aligned-dna-sequences.fasta')
+
+        obs = obs.astype(str)
+
+        index = pd.Index(['SEQUENCE1', 'SEQUENCE2'])
+        exp = pd.Series(['------------------------ACGTACGTACGTACGTACGTAC'
+                         'GTACGTACGTACGTACGTACGTACGTACGTACGTACGTACGT',
+                         'ACGTACGTACGTACGTACGTACGTACGTACGTACGTACGTACGTAC'
+                         'GTACGTACGTACGTACGTACGTACGTACGTACGTACGTACGT'],
+                        index=index, dtype=object)
+
+        assert_series_equal(exp, obs)
+
+    def test_series_to_aligned_dnafasta_format(self):
+        transformer = self.get_transformer(pd.Series, AlignedDNAFASTAFormat)
+
+        index = pd.Index(['SEQUENCE1', 'SEQUENCE2'])
+        input = pd.Series(['------------------------ACGTACGTACGTACGTACGTAC'
+                           'GTACGTACGTACGTACGTACGTACGTACGTACGTACGTACGT',
+                           'ACGTACGTACGTACGTACGTACGTACGTACGTACGTACGTACGTAC'
+                           'GTACGTACGTACGTACGTACGTACGTACGTACGTACGTACGT'],
+                          index=index, dtype=object)
+
+        obs = transformer(input)
+
+        self.assertIsInstance(obs, AlignedDNAFASTAFormat)
+
+        obs_lines = list(open(str(obs)))
+        self.assertEqual(obs_lines[0], '>SEQUENCE1\n')
+        self.assertEqual(obs_lines[1],
+                         '------------------------ACGTACGTACGTACGTACGTAC'
+                         'GTACGTACGTACGTACGTACGTACGTACGTACGTACGTACGT\n')
+        self.assertEqual(obs_lines[2], '>SEQUENCE2\n')
+        self.assertEqual(obs_lines[3],
+                         'ACGTACGTACGTACGTACGTACGTACGTACGTACGTACGTACGTAC'
+                         'GTACGTACGTACGTACGTACGTACGTACGTACGTACGTACGT\n')
+
+    def test_aligned_dna_fasta_format_to_dna_iterator(self):
+        input, obs = self.transform_format(
+            AlignedDNAFASTAFormat, DNAIterator,
+            filename='aligned-dna-sequences.fasta')
+
+        exp = skbio.read(str(input), format='fasta', constructor=skbio.DNA)
+
+        for observed, expected in zip(obs, exp):
+            self.assertEqual(observed, expected)
+
+
+class TestDifferentialTransformer(TestPluginBase):
+    package = 'q2_types.feature_data.tests'
+
+    def test_differential_to_df(self):
+
+        _, obs = self.transform_format(DifferentialFormat, pd.DataFrame,
+                                       filename='differentials.tsv')
+
+        # sniff to see if the first 4 feature ids are the same
+        exp = ['F0', 'F1', 'F2', 'F3']
+        obs = list(obs.index[:4])
+        self.assertListEqual(exp, obs)
+
+    def test_differential_to_md(self):
+
+        _, obs = self.transform_format(DifferentialFormat, qiime2.Metadata,
+                                       filename='differentials.tsv')
+        obs = obs.to_dataframe()
+        # sniff to see if the first 4 feature ids are the same
+        exp = ['F0', 'F1', 'F2', 'F3']
+        obs = list(obs.index[:4])
+        self.assertListEqual(exp, obs)
+
+    def test_df_to_differential(self):
+        transformer = self.get_transformer(pd.DataFrame, DifferentialFormat)
+
+        index = pd.Index(['SEQUENCE1', 'SEQUENCE2', 'SEQUENCE3'])
+        index.name = 'featureid'
+        input = pd.DataFrame(
+            [-1.3, 0.1, 1.2], index=index, columns=['differential'],
+            dtype=float)
+
+        obs = transformer(input)
+
+        self.assertIsInstance(obs, DifferentialFormat)
+
 
 if __name__ == '__main__':
     unittest.main()
