@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2019, QIIME 2 development team.
+# Copyright (c) 2016-2020, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -24,20 +24,6 @@ from q2_types.feature_table._transformer import (_parse_biom_table_v100,
 class TestTransformers(TestPluginBase):
     package = 'q2_types.feature_table.tests'
 
-    def test_biom_table_to_biom_v100_format(self):
-        filepath = self.get_data_path('feature-table_v100.biom')
-        transformer = self.get_transformer(biom.Table, BIOMV100Format)
-        input = biom.load_table(filepath)
-
-        obs = transformer(input)
-        obs = biom.load_table(str(obs))
-
-        exp = input
-        self.assertEqual(obs.ids(axis='observation').all(),
-                         exp.ids(axis='observation').all())
-        self.assertEqual(obs.ids(axis='sample').all(),
-                         exp.ids(axis='sample').all())
-
     def test_biom_v100_format_to_biom_table(self):
         input, obs = self.transform_format(BIOMV100Format, biom.Table,
                                            filename='feature-table_v100.biom')
@@ -111,17 +97,6 @@ class TestTransformers(TestPluginBase):
         self.assertEqual(obs.ids(axis='sample').all(),
                          exp.ids(axis='sample').all())
 
-    def test_biom_v210_format_to_biom_v100_format(self):
-        input, obs = self.transform_format(BIOMV210Format, BIOMV100Format,
-                                           filename='feature-table_v210.biom')
-        exp = biom.load_table(str(input))
-        obs = biom.load_table(str(obs))
-
-        self.assertEqual(obs.ids(axis='observation').all(),
-                         exp.ids(axis='observation').all())
-        self.assertEqual(obs.ids(axis='sample').all(),
-                         exp.ids(axis='sample').all())
-
     def test_to_pandas_data_frame_to_biom_v210_format(self):
         filepath = self.get_data_path('feature-table_v100.biom')
         transformer1 = self.get_transformer(BIOMV100Format, pd.DataFrame)
