@@ -1,11 +1,12 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2019, QIIME 2 development team.
+# Copyright (c) 2016-2020, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
 # The full license is in the file LICENSE, distributed with this software.
 # ----------------------------------------------------------------------------
 
+import functools
 import unittest
 import os
 import shutil
@@ -25,13 +26,15 @@ from q2_types.per_sample_sequences import (
     SingleEndFastqManifestPhred64,
     PairedEndFastqManifestPhred33,
     PairedEndFastqManifestPhred64,
+    FastqAbsolutePathManifestFormat,
     FastqManifestFormat,
     SingleEndFastqManifestPhred33V2,
     SingleEndFastqManifestPhred64V2,
     PairedEndFastqManifestPhred33V2,
     PairedEndFastqManifestPhred64V2,
-    QIIME1DemuxDirFmt)
-from q2_types.per_sample_sequences._transformer import (
+    QIIME1DemuxDirFmt,
+    FastqGzFormat)
+from q2_types.per_sample_sequences._util import (
     _validate_header,
     _validate_single_end_fastq_manifest_directions,
     _validate_paired_end_fastq_manifest_directions,
@@ -40,6 +43,13 @@ from q2_types.per_sample_sequences._transformer import (
 from qiime2.plugin.testing import TestPluginBase
 
 
+_parse_and_validate_manifest_partial = functools.partial(
+    _parse_and_validate_manifest,
+    abs_manifest_fmt=FastqAbsolutePathManifestFormat,
+    manifest_fmt=FastqManifestFormat,
+)
+
+
 class TestTransformers(TestPluginBase):
     package = "q2_types.per_sample_sequences.tests"
 
@@ -119,6 +129,24 @@ class TestTransformers(TestPluginBase):
                 SingleLanePerSampleSingleEndFastqDirFmt,
                 QIIME1DemuxDirFmt, filenames=filenames)
 
+    def test_casava_one_eight_laneless_per_sample_dirfmt_to_slpspefd(self):
+        filenames = ('Human-Kneecap_S1_R1_001.fastq.gz',
+                     'Human-Armpit_S2_R1_001.fastq.gz')
+
+        input, dirfmt = self.transform_format(
+            CasavaOneEightLanelessPerSampleDirFmt,
+            SingleLanePerSamplePairedEndFastqDirFmt, filenames=filenames
+        )
+        expected_filepaths = ['Human-Kneecap_S1_L001_R1_001.fastq.gz',
+                              'Human-Armpit_S2_L001_R1_001.fastq.gz']
+
+        for path, view in dirfmt.sequences.iter_views(FastqGzFormat):
+            self.assertIn(path.name, expected_filepaths)
+
+        df = dirfmt.manifest.view(pd.DataFrame)
+        for name in df['forward']:
+            self.assertTrue((dirfmt.path / name).exists())
+
     def test_casava_one_eight_single_lane_per_sample_dirfmt_to_slpssefdf(self):
         filenames = ('Human-Kneecap_S1_L001_R1_001.fastq.gz',)
         input, obs = self.transform_format(
@@ -198,7 +226,7 @@ class TestTransformers(TestPluginBase):
     def test_fastqmanifest_single(self):
         _, dirfmt = self.transform_format(
             CasavaOneEightSingleLanePerSampleDirFmt,
-            SingleLanePerSamplePairedEndFastqDirFmt,
+            SingleLanePerSampleSingleEndFastqDirFmt,
             filenames=('Human-Kneecap_S1_L001_R1_001.fastq.gz',
                        'Human-Armpit_S2_L001_R1_001.fastq.gz'),
         )
@@ -226,6 +254,43 @@ class TestTransformers(TestPluginBase):
         self.assertTrue(os.path.exists(df['forward'].loc['Human-Kneecap']))
         self.assertTrue(os.path.exists(df['reverse'].loc['Human-Kneecap']))
 
+    def test_slpssefdf_to_casava_one_eight_single_lane_per_sample_dirfmt(self):
+        filenames = ('single-end-two-sample-data1/MANIFEST',
+                     'metadata.yml',
+                     'Human-Kneecap_S1_L001_R1_001.fastq.gz',
+                     'Human-Armpit_S2_L001_R1_001.fastq.gz')
+
+        input, obs = self.transform_format(
+            SingleLanePerSampleSingleEndFastqDirFmt,
+            CasavaOneEightSingleLanePerSampleDirFmt, filenames=filenames
+        )
+
+        self.assertEqual(input.validate(), None)
+
+        exp_fp = ['Human-Armpit_S2_L001_R1_001.fastq.gz',
+                  'Human-Kneecap_S1_L001_R1_001.fastq.gz']
+        obs_fp = [str(fp) for fp, _ in obs.sequences.iter_views(FastqGzFormat)]
+
+        self.assertEqual(obs_fp, exp_fp)
+
+    def test_slpspefdf_to_casava_one_eight_single_lane_per_sample_dirfmt(self):
+        filenames = ('Human-Kneecap_S1_L001_R1_001.fastq.gz',
+                     'paired_end_data/Human-Kneecap_S1_L001_R2_001.fastq.gz',
+                     'paired_end_data/MANIFEST',
+                     'metadata.yml')
+        input, obs = self.transform_format(
+            SingleLanePerSamplePairedEndFastqDirFmt,
+            CasavaOneEightSingleLanePerSampleDirFmt, filenames=filenames
+        )
+
+        self.assertEqual(input.validate(), None)
+
+        exp_fp = ['Human-Kneecap_S1_L001_R1_001.fastq.gz',
+                  'Human-Kneecap_S1_L001_R2_001.fastq.gz']
+        obs_fp = [str(fp) for fp, _ in obs.sequences.iter_views(FastqGzFormat)]
+
+        self.assertEqual(obs_fp, exp_fp)
+
 
 class TestFastqManifestTransformers(TestPluginBase):
     package = "q2_types.per_sample_sequences.tests"
@@ -776,24 +841,24 @@ class TestFastqManifestTransformers(TestPluginBase):
         with self.assertRaisesRegex(
                 ValueError, "Expected.*absolute-filepath.*found "
                             "'sample-id,absolute-filepath'.$"):
-            _parse_and_validate_manifest(manifest, single_end=True,
-                                         absolute=True)
+            _parse_and_validate_manifest_partial(
+                manifest, single_end=True, absolute=True)
 
         manifest = io.StringIO(
             'sample-id,absolute-filepath,direction\n'
             'abc,/hello/world\n'
             'abc,/hello/world,forward\n')
         with self.assertRaisesRegex(ValueError, 'Empty cells'):
-            _parse_and_validate_manifest(manifest, single_end=True,
-                                         absolute=True)
+            _parse_and_validate_manifest_partial(
+                manifest, single_end=True, absolute=True)
 
         manifest = io.StringIO(
             'sample-id,absolute-filepath,direction\n'
             'abc,/hello/world,forward\n'
             'xyz,/hello/world,forward,extra-field')
         with self.assertRaisesRegex(ValueError, 'issue parsing the manifest'):
-            _parse_and_validate_manifest(manifest, single_end=True,
-                                         absolute=True)
+            _parse_and_validate_manifest_partial(
+                manifest, single_end=True, absolute=True)
 
         manifest = io.StringIO(
             'sample-id,absolute-filepath,direction\n'
@@ -801,8 +866,8 @@ class TestFastqManifestTransformers(TestPluginBase):
             'xyz,world,forward')
         with self.assertRaisesRegex(ValueError,
                                     'absolute but found relative path'):
-            _parse_and_validate_manifest(manifest, single_end=True,
-                                         absolute=True)
+            _parse_and_validate_manifest_partial(
+                manifest, single_end=True, absolute=True)
 
         manifest = io.StringIO(
             'sample-id,absolute-filepath,direction\n'
@@ -810,8 +875,8 @@ class TestFastqManifestTransformers(TestPluginBase):
             'abc,world,reverse')
         with self.assertRaisesRegex(ValueError,
                                     'absolute but found relative path'):
-            _parse_and_validate_manifest(manifest, single_end=False,
-                                         absolute=True)
+            _parse_and_validate_manifest_partial(
+                manifest, single_end=False, absolute=True)
 
         manifest = io.StringIO(
             'sample-id,filename,direction\n'
@@ -819,8 +884,8 @@ class TestFastqManifestTransformers(TestPluginBase):
             'xyz,/snap/crackle/pop/world,forward')
         with self.assertRaisesRegex(ValueError,
                                     'relative but found absolute path'):
-            _parse_and_validate_manifest(manifest, single_end=True,
-                                         absolute=False)
+            _parse_and_validate_manifest_partial(
+                manifest, single_end=True, absolute=False)
 
         manifest = io.StringIO(
             'sample-id,filename,direction\n'
@@ -828,8 +893,8 @@ class TestFastqManifestTransformers(TestPluginBase):
             'abc,/snap/crackle/pop/world,reverse')
         with self.assertRaisesRegex(ValueError,
                                     'relative but found absolute path'):
-            _parse_and_validate_manifest(manifest, single_end=False,
-                                         absolute=False)
+            _parse_and_validate_manifest_partial(
+                manifest, single_end=False, absolute=False)
 
     def test_parse_and_validate_manifest_expand_vars(self):
         expected_fp = os.path.join(self.temp_dir.name, 'manifest.txt')
@@ -839,8 +904,8 @@ class TestFastqManifestTransformers(TestPluginBase):
         manifest = io.StringIO(
             'sample-id,absolute-filepath,direction\n'
             'abc,$TESTENVGWAR/manifest.txt,forward')
-        manifest = _parse_and_validate_manifest(manifest, single_end=True,
-                                                absolute=True)
+        manifest = _parse_and_validate_manifest_partial(
+            manifest, single_end=True, absolute=True)
         del os.environ['TESTENVGWAR']
 
         self.assertEqual(manifest.iloc[0]['absolute-filepath'], expected_fp)
